==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Help/About/ts/About_sk.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sk">
<context>
    <name>About</name>
    <message>
        <location filename="../About.js" line="+62"/>
        <source>About %1</source>
        <translation>O %1</translation>
    </message>
    <message>
        <location line="+47"/>
        <source>Revision:</source>
        <translation>Revízia:</translation>
    </message>
    <message>
        <location line="+15"/>
        <source>%1 is based on QCAD, a free (open source) software.</source>
        <translation>%1 je založený na QCAD-e, volne šíriteľný (open source) software.</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>This means that everyone can &lt;a href=&apos;%1&apos;&gt;get involved&lt;/a&gt;!</source>
        <translation>To znamená, že sa každý môže &lt;a href=&apos;%1&apos;&gt; zapojiť &lt;/a&gt; !</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Portions of this software © 2008-2016 The Qt Company Ltd.</source>
        <translation>Súčasti tohto software © 2008-2016 The Qt Company Ltd.</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>The program is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.</source>
        <translation>Tento program je šírený v nádeji, že bude užitočný, ale BEZ ZÁRUKY - dokonca bez predpokladanej záruky obchodovateľnosti na konkrétny účel.</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Plugins</source>
        <translation>Zásuvné moduly</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>No information available</source>
        <translation>Žiadne dostupné informácie</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Plugin:</source>
        <translation>Zásuvný modul:</translation>
    </message>
    <message>
        <location line="+25"/>
        <source>ID:</source>
        <translation>ID:</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Description:</source>
        <translation>Popis:</translation>
    </message>
    <message>
        <location line="+4"/>
        <location line="+4"/>
        <location line="+4"/>
        <source>Unknown</source>
        <translation>Neznáme</translation>
    </message>
    <message>
        <location line="-115"/>
        <location line="+108"/>
        <source>Version:</source>
        <translation>Verzia:</translation>
    </message>
    <message>
        <location line="-95"/>
        <location line="+99"/>
        <source>Qt Version:</source>
        <translation>Qt Verzia:</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>License:</source>
        <translation>Licencia:</translation>
    </message>
    <message>
        <location line="-109"/>
        <location line="+118"/>
        <location line="+12"/>
        <source>Internet:</source>
        <translation>Internet:</translation>
    </message>
    <message>
        <location line="-128"/>
        <source>Build Date:</source>
        <translation>Dátum vytvorenia:</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Architecture:</source>
        <translation>Architektúra:</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Compiler:</source>
        <translation>Kompilátor:</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>%1 is an application for computer-aided design (CAD).</source>
        <translation>%1 je program pre 2D projektovanie a konštruovanie (CAD).</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>%1 is free (open source) software.</source>
        <translation>%1 je bezplatný software (open source).</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Plugins and script add-ons are subject to their respective license (see &apos;Plugins&apos; tab).</source>
        <translation>Zásuvné moduly a skripty podliehajú vlastným licenciám (pozri záložku Zásuvné moduly).</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>All brand or product names are trademarks or registered trademarks of their respective holders.</source>
        <translation>Všetky značky alebo názvy produktov sú ochrannými známkami alebo registrovanými ochrannými známkami príslušných vlastníkov.</translation>
    </message>
    <message>
        <source>Portions of this software © 2013 Digia Plc.</source>
        <translation type="vanished">Súčasti tohto software © 2013 Digia s.r.o..</translation>
    </message>
    <message>
        <source>Portions of this software © 2012 Nokia Corporation and/or its subsidiary(-ies).</source>
        <translation type="vanished">Súčasti tohto softvéru © 2012 Spoločnosť Nokia a / alebo jej dcérske spoločnosti.</translation>
    </message>
    <message>
        <location line="+22"/>
        <source>No plugins found.</source>
        <translation>Nenašiel sa žiadny modul.</translation>
    </message>
    <message>
        <location line="+93"/>
        <source>Active</source>
        <translation>Aktívne</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Inactive (restart)</source>
        <translation>Neaktívny (reštart)</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Trial Version:</source>
        <translation>Skúšobná verzia:</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>File:</source>
        <translation>Súbor:</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Error:</source>
        <translation>Chyba:</translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Script Add-Ons</source>
        <translation>Skripty Doplnkov</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>No script add-ons found.</source>
        <translation>Nenašiel sa žiadny prídavný skript.</translation>
    </message>
    <message>
        <location line="+40"/>
        <source>Credits</source>
        <translation>Prispievatelia</translation>
    </message>
    <message>
        <location filename="../AboutInit.js" line="+2"/>
        <source>&amp;About...</source>
        <translation>O progr&amp;ame...</translation>
    </message>
</context>
<context>
    <name>AboutCredits</name>
    <message>
        <location filename="../AboutCredits.js" line="+4"/>
        <source>Programming</source>
        <translation>Programovanie</translation>
    </message>
    <message>
        <location line="+42"/>
        <source>Translations</source>
        <translation>Preklady</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Templates</source>
        <translation>Šablóny</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Icons</source>
        <translation>Ikony</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Testing, Feedback and Minor Fixes</source>
        <translation>Testovanie, spätná väzba a drobné opravy</translation>
    </message>
</context>
<context>
    <name>AboutDialog</name>
    <message>
        <location filename="../AboutDialog.ui" line="+105"/>
        <source>About</source>
        <translation>O programe</translation>
    </message>
    <message>
        <source>about:blank</source>
        <translation type="vanished">about:blank</translation>
    </message>
    <message>
        <location line="+67"/>
        <source>Credits</source>
        <translation>Tvorcovia</translation>
    </message>
    <message>
        <location line="+67"/>
        <source>Plugins</source>
        <translation>Zásuvné moduly</translation>
    </message>
    <message>
        <location line="+67"/>
        <source>Scripts</source>
        <translation>Skripty</translation>
    </message>
    <message>
        <location line="+67"/>
        <source>System</source>
        <translation>Systém</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Help/About/ts/About_sk.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sk">
<context>
    <name>About</name>
    <message>
        <location filename="../About.js" line="+63"/>
        <source>About %1</source>
        <translation>O %1</translation>
    </message>
    <message>
        <location line="+57"/>
        <source>Revision:</source>
        <translation>Revízia:</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>%1 is based on QCAD, a free (open source) software.</source>
        <translation>%1 je založený na QCAD-e, volne šíriteľný (open source) software.</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>This means that everyone can &lt;a href=&apos;%1&apos;&gt;get involved&lt;/a&gt;!</source>
        <translation>To znamená, že sa každý môže &lt;a href=&apos;%1&apos;&gt; zapojiť &lt;/a&gt; !</translation>
    </message>
    <message>
        <source>Portions of this software © 2008-2016 The Qt Company Ltd.</source>
        <translation type="vanished">Súčasti tohto software © 2008-2016 The Qt Company Ltd.</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>The program is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.</source>
        <translation>Tento program je šírený v nádeji, že bude užitočný, ale BEZ ZÁRUKY - dokonca bez predpokladanej záruky obchodovateľnosti na konkrétny účel.</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Plugins</source>
        <translation>Zásuvné moduly</translation>
    </message>
    <message>
        <location line="+31"/>
        <source>No information available</source>
        <translation>Žiadne dostupné informácie</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Plugin:</source>
        <translation>Zásuvný modul:</translation>
    </message>
    <message>
        <location line="+25"/>
        <source>ID:</source>
        <translation>ID:</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Description:</source>
        <translation>Popis:</translation>
    </message>
    <message>
        <location line="+4"/>
        <location line="+4"/>
        <location line="+4"/>
        <source>Unknown</source>
        <translation>Neznáme</translation>
    </message>
    <message>
        <location line="-128"/>
        <location line="+121"/>
        <source>Version:</source>
        <translation>Verzia:</translation>
    </message>
    <message>
        <location line="-111"/>
        <location line="+115"/>
        <source>Qt Version:</source>
        <translation>Qt Verzia:</translation>
    </message>
    <message>
        <source>Portions of this software © 2008-2017 The Qt Company Ltd.</source>
        <translation type="vanished">Súčasti tohto software © 2008-2017 The Qt Company Ltd.</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>License:</source>
        <translation>Licencia:</translation>
    </message>
    <message>
        <location line="-125"/>
        <location line="+134"/>
        <location line="+11"/>
        <source>Internet:</source>
        <translation>Internet:</translation>
    </message>
    <message>
        <location line="-143"/>
        <source>Build Date:</source>
        <translation>Dátum vytvorenia:</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Architecture:</source>
        <translation>Architektúra:</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Compiler:</source>
        <translation>Kompilátor:</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>License Key:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+5"/>
        <source>%1 is an application for computer-aided design (CAD).</source>
        <translation>%1 je program pre 2D projektovanie a konštruovanie (CAD).</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>%1 is free (open source) software.</source>
        <translation>%1 je bezplatný software (open source).</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Plugins and script add-ons are subject to their respective license (see &apos;Plugins&apos; tab).</source>
        <translation>Zásuvné moduly a skripty podliehajú vlastným licenciám (pozri záložku Zásuvné moduly).</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>All brand or product names are trademarks or registered trademarks of their respective holders.</source>
        <translation>Všetky značky alebo názvy produktov sú ochrannými známkami alebo registrovanými ochrannými známkami príslušných vlastníkov.</translation>
    </message>
    <message>
        <source>Portions of this software © 2013 Digia Plc.</source>
        <translation type="vanished">Súčasti tohto software © 2013 Digia s.r.o..</translation>
    </message>
    <message>
        <source>Portions of this software © 2012 Nokia Corporation and/or its subsidiary(-ies).</source>
        <translation type="vanished">Súčasti tohto softvéru © 2012 Spoločnosť Nokia a / alebo jej dcérske spoločnosti.</translation>
    </message>
    <message>
        <source>Portions of this software © 2008-2018 The Qt Company Ltd.</source>
        <translation type="obsolete">Súčasti tohto software © 2008-2017 The Qt Company Ltd. {2008-2018 ?}</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Portions of this software © %1 The Qt Company Ltd.</source>
        <translation>Časť tohto softvéru © %1 The Qt Company Ltd.</translation>
    </message>
    <message>
        <location line="+19"/>
        <source>No plugins found.</source>
        <translation>Nenašiel sa žiadny modul.</translation>
    </message>
    <message>
        <location line="+99"/>
        <source>Active</source>
        <translation>Aktívne</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Inactive (restart)</source>
        <translation>Neaktívny (reštart)</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Trial Version:</source>
        <translation>Skúšobná verzia:</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>File:</source>
        <translation>Súbor:</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Error:</source>
        <translation>Chyba:</translation>
    </message>
    <message>
        <location line="+22"/>
        <source>Script Add-Ons</source>
        <translation>Skripty Doplnkov</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>No script add-ons found.</source>
        <translation>Nenašiel sa žiadny prídavný skript.</translation>
    </message>
    <message>
        <location line="+45"/>
        <source>Credits</source>
        <translation>Prispievatelia</translation>
    </message>
    <message>
        <location filename="../AboutInit.js" line="+2"/>
        <source>&amp;About...</source>
        <translation>O progr&amp;ame...</translation>
    </message>
</context>
<context>
    <name>AboutCredits</name>
    <message>
        <location filename="../AboutCredits.js" line="+4"/>
        <source>Programming</source>
        <translation>Programovanie</translation>
    </message>
    <message>
        <location line="+48"/>
        <source>Translations</source>
        <translation>Preklady</translation>
    </message>
    <message>
        <location line="+15"/>
        <source>Templates</source>
        <translation>Šablóny</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Icons</source>
        <translation>Ikony</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Testing, Feedback and Minor Fixes</source>
        <translation>Testovanie, spätná väzba a drobné opravy</translation>
    </message>
</context>
<context>
    <name>AboutDialog</name>
    <message>
        <location filename="../AboutDialog.ui" line="+105"/>
        <source>About</source>
        <translation>O programe</translation>
    </message>
    <message>
        <source>about:blank</source>
        <translation type="vanished">about:blank</translation>
    </message>
    <message>
        <location line="+67"/>
        <source>Credits</source>
        <translation>Tvorcovia</translation>
    </message>
    <message>
        <location line="+67"/>
        <source>Plugins</source>
        <translation>Zásuvné moduly</translation>
    </message>
    <message>
        <location line="+67"/>
        <source>Scripts</source>
        <translation>Skripty</translation>
    </message>
    <message>
        <location line="+67"/>
        <source>System</source>
        <translation>Systém</translation>
    </message>
</context>
</TS>
